@@ -4,6 +4,7 @@ import (
 	"fmt"
 	"os"
 
+	"github.com/go-task/task/v3/internal/experiments"
 	"github.com/go-task/task/v3/taskfile/ast"
 )
 
@@ -11,15 +12,15 @@ func Get(t *ast.Task) []string {
 	if t.Env == nil {
 		return nil
 	}
-
 	environ := os.Environ()
 	for k, v := range t.Env.ToCacheMap() {
 		if !isTypeAllowed(v) {
 			continue
 		}
-
-		if _, alreadySet := os.LookupEnv(k); alreadySet {
-			continue
+		if !experiments.EnvPrecedence.Enabled {
+			if _, alreadySet := os.LookupEnv(k); alreadySet {
+				continue
+			}
 		}
 		environ = append(environ, fmt.Sprintf("%s=%v", k, v))
 	}
