@@ -38,6 +38,7 @@ var (
 	Version     bool
 	Help        bool
 	Init        bool
+	Completion  string
 	List        bool
 	ListAll     bool
 	ListJson    bool
@@ -65,6 +66,7 @@ var (
 	Experiments bool
 	Download    bool
 	Offline     bool
+	ClearCache  bool
 	Timeout     time.Duration
 )
 
@@ -79,6 +81,7 @@ func init() {
 	pflag.BoolVar(&Version, "version", false, "Show Task version.")
 	pflag.BoolVarP(&Help, "help", "h", false, "Shows Task usage.")
 	pflag.BoolVarP(&Init, "init", "i", false, "Creates a new Taskfile.yml in the current folder.")
+	pflag.StringVar(&Completion, "completion", "", "Generates shell completion script.")
 	pflag.BoolVarP(&List, "list", "l", false, "Lists tasks with description of current Taskfile.")
 	pflag.BoolVarP(&ListAll, "list-all", "a", false, "Lists tasks with or without a description.")
 	pflag.BoolVarP(&ListJson, "json", "j", false, "Formats task list as JSON.")
@@ -119,6 +122,7 @@ func init() {
 		pflag.BoolVar(&Download, "download", false, "Downloads a cached version of a remote Taskfile.")
 		pflag.BoolVar(&Offline, "offline", false, "Forces Task to only use local or cached Taskfiles.")
 		pflag.DurationVar(&Timeout, "timeout", time.Second*10, "Timeout for downloading remote Taskfiles.")
+		pflag.BoolVar(&ClearCache, "clear-cache", false, "Clear the remote cache.")
 	}
 
 	pflag.Parse()
@@ -129,6 +133,10 @@ func Validate() error {
 		return errors.New("task: You can't set both --download and --offline flags")
 	}
 
+	if Download && ClearCache {
+		return errors.New("task: You can't set both --download and --clear-cache flags")
+	}
+
 	if Global && Dir != "" {
 		log.Fatal("task: You can't set both --global and --dir")
 		return nil
