@@ -17,7 +17,9 @@ import (
 // An HTTPNode is a node that reads a Taskfile from a remote location via HTTP.
 type HTTPNode struct {
 	*BaseNode
-	URL *url.URL
+	URL     *url.URL
+	logger  *logger.Logger
+	timeout time.Duration
 }
 
 func NewHTTPNode(
@@ -36,18 +38,12 @@ func NewHTTPNode(
 	if url.Scheme == "http" && !insecure {
 		return nil, &errors.TaskfileNotSecureError{URI: entrypoint}
 	}
-	ctx, cf := context.WithTimeout(context.Background(), timeout)
-	defer cf()
-	url, err = RemoteExists(ctx, l, url)
-	if err != nil {
-		return nil, err
-	}
-	if errors.Is(ctx.Err(), context.DeadlineExceeded) {
-		return nil, &errors.TaskfileNetworkTimeoutError{URI: url.String(), Timeout: timeout}
-	}
+
 	return &HTTPNode{
 		BaseNode: base,
 		URL:      url,
+		timeout:  timeout,
+		logger:   l,
 	}, nil
 }
 
@@ -60,6 +56,11 @@ func (node *HTTPNode) Remote() bool {
 }
 
 func (node *HTTPNode) Read(ctx context.Context) ([]byte, error) {
+	url, err := RemoteExists(ctx, node.logger, node.URL, node.timeout)
+	if err != nil {
+		return nil, err
+	}
+	node.URL = url
 	req, err := http.NewRequest("GET", node.URL.String(), nil)
 	if err != nil {
 		return nil, errors.TaskfileFetchFailedError{URI: node.URL.String()}
@@ -67,6 +68,9 @@ func (node *HTTPNode) Read(ctx context.Context) ([]byte, error) {
 
 	resp, err := http.DefaultClient.Do(req.WithContext(ctx))
 	if err != nil {
+		if errors.Is(err, context.DeadlineExceeded) {
+			return nil, &errors.TaskfileNetworkTimeoutError{URI: node.URL.String(), Timeout: node.timeout}
+		}
 		return nil, errors.TaskfileFetchFailedError{URI: node.URL.String()}
 	}
 	defer resp.Body.Close()
@@ -110,3 +114,8 @@ func (node *HTTPNode) ResolveDir(dir string) (string, error) {
 	entrypointDir := filepath.Dir(node.Dir())
 	return filepathext.SmartJoin(entrypointDir, path), nil
 }
+
+func (node *HTTPNode) FilenameAndLastDir() (string, string) {
+	dir, filename := filepath.Split(node.URL.Path)
+	return filepath.Base(dir), filename
+}
