@@ -11,6 +11,7 @@ import (
 	"github.com/go-task/task/v3/internal/execext"
 	"github.com/go-task/task/v3/internal/filepathext"
 	"github.com/go-task/task/v3/internal/fingerprint"
+	"github.com/go-task/task/v3/internal/omap"
 	"github.com/go-task/task/v3/internal/templater"
 	"github.com/go-task/task/v3/taskfile/ast"
 )
@@ -72,6 +73,7 @@ func (e *Executor) compiledTask(call *ast.Call, evaluateShVars bool) (*ast.Task,
 		Location:             origTask.Location,
 		Requires:             origTask.Requires,
 		Watch:                origTask.Watch,
+		Namespace:            origTask.Namespace,
 	}
 	new.Dir, err = execext.Expand(new.Dir)
 	if err != nil {
@@ -160,6 +162,12 @@ func (e *Executor) compiledTask(call *ast.Call, evaluateShVars bool) (*ast.Task,
 				}
 				continue
 			}
+			// Defer commands are replaced in a lazy manner because
+			// we need to include EXIT_CODE.
+			if cmd.Defer {
+				new.Cmds = append(new.Cmds, cmd.DeepCopy())
+				continue
+			}
 			newCmd := cmd.DeepCopy()
 			newCmd.Cmd = templater.Replace(cmd.Cmd, cache)
 			newCmd.Task = templater.Replace(cmd.Task, cache)
@@ -221,8 +229,8 @@ func (e *Executor) compiledTask(call *ast.Call, evaluateShVars bool) (*ast.Task,
 	}
 
 	if len(origTask.Status) > 0 {
-		timestampChecker := fingerprint.NewTimestampChecker(e.TempDir, e.Dry)
-		checksumChecker := fingerprint.NewChecksumChecker(e.TempDir, e.Dry)
+		timestampChecker := fingerprint.NewTimestampChecker(e.TempDir.Fingerprint, e.Dry)
+		checksumChecker := fingerprint.NewChecksumChecker(e.TempDir.Fingerprint, e.Dry)
 
 		for _, checker := range []fingerprint.SourcesCheckable{timestampChecker, checksumChecker} {
 			value, err := checker.Value(&new)
@@ -264,9 +272,13 @@ func itemsFromFor(
 ) ([]any, []string, error) {
 	var keys []string // The list of keys to loop over (only if looping over a map)
 	var values []any  // The list of values to loop over
+	// Get the list from a matrix
+	if f.Matrix.Len() != 0 {
+		return asAnySlice(product(f.Matrix)), nil, nil
+	}
 	// Get the list from the explicit for list
-	if f.List != nil && len(f.List) > 0 {
-		values = f.List
+	if len(f.List) > 0 {
+		return f.List, nil, nil
 	}
 	// Get the list from the task sources
 	if f.From == "sources" {
@@ -315,3 +327,39 @@ func itemsFromFor(
 	}
 	return values, keys, nil
 }
+
+// product generates the cartesian product of the input map of slices.
+func product(inputMap omap.OrderedMap[string, []any]) []map[string]any {
+	if inputMap.Len() == 0 {
+		return nil
+	}
+
+	// Start with an empty product result
+	result := []map[string]any{{}}
+
+	// Iterate over each slice in the slices
+	_ = inputMap.Range(func(key string, slice []any) error {
+		var newResult []map[string]any
+
+		// For each combination in the current result
+		for _, combination := range result {
+			// Append each element from the current slice to the combinations
+			for _, item := range slice {
+				newComb := make(map[string]any, len(combination))
+				// Copy the existing combination
+				for k, v := range combination {
+					newComb[k] = v
+				}
+				// Add the current item with the corresponding key
+				newComb[key] = item
+				newResult = append(newResult, newComb)
+			}
+		}
+
+		// Update result with the new combinations
+		result = newResult
+		return nil
+	})
+
+	return result
+}
